@@ -25,6 +25,8 @@
 
 #include "debug.h"
 
+#include "configuration.h"
+
 #include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/ConnectionSettings>
 #include <NetworkManagerQt/GenericTypes>
@@ -33,10 +35,12 @@
 #include <NetworkManagerQt/VpnSetting>
 #include <NetworkManagerQt/WirelessSecuritySetting>
 #include <NetworkManagerQt/WirelessSetting>
+#include <NetworkManagerQt/WireguardSetting>
 
 #include <QStringBuilder>
 #include <QDialog>
 
+#include <KLocalizedString>
 #include <KPluginFactory>
 #include <KWindowSystem>
 #include <KConfig>
@@ -69,7 +73,7 @@ NMVariantMapMap SecretAgent::GetSecrets(const NMVariantMapMap &connection, const
     qCDebug(PLASMA_NM) << "Flags:" << flags;
 
     const QString callId = connection_path.path() % setting_name;
-    Q_FOREACH (const SecretsRequest & request, m_calls) {
+    for (const SecretsRequest &request : m_calls) {
         if (request == callId) {
             qCWarning(PLASMA_NM) << "GetSecrets was called again! This should not happen, cancelling first call" << connection_path.path() << setting_name;
             CancelGetSecrets(connection_path, setting_name);
@@ -89,7 +93,6 @@ NMVariantMapMap SecretAgent::GetSecrets(const NMVariantMapMap &connection, const
     m_calls << request;
 
     processNext();
-
     return NMVariantMapMap();
 }
 
@@ -229,7 +232,7 @@ void SecretAgent::dialogAccepted()
                     }
 
                     // Load temporary secrets from auth dialog which are not returned to NM
-                    Q_FOREACH (const QString &key, tmpOpenconnectSecrets.keys()) {
+                    for (const QString &key : tmpOpenconnectSecrets.keys()) {
                         if (secrets.contains(QLatin1Literal("save_passwords")) && secrets.value(QLatin1Literal("save_passwords")) == QLatin1String("yes")) {
                             data.insert(key + QLatin1String("-flags"), QString::number(NetworkManager::Setting::AgentOwned));
                         } else {
@@ -357,6 +360,7 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
     const bool userRequested = request.flags & UserRequested;
     const bool allowInteraction = request.flags & AllowInteraction;
     const bool isVpn = (setting->type() == NetworkManager::Setting::Vpn);
+    const bool isWireGuard = (setting->type() == NetworkManager::Setting::WireGuard);
 
     if (isVpn) {
         NetworkManager::VpnSetting::Ptr vpnSetting = connectionSettings->setting(NetworkManager::Setting::Vpn).dynamicCast<NetworkManager::VpnSetting>();
@@ -396,7 +400,7 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
 
     if (!secretsMap.isEmpty()) {
         setting->secretsFromStringMap(secretsMap);
-        if (!isVpn && setting->needSecrets(requestNew).isEmpty()) {
+        if (!(isVpn || isWireGuard) && setting->needSecrets(requestNew).isEmpty()) {
             // Enough secrets were retrieved from storage
             request.connection[request.setting_name] = setting->secretsToMap();
             sendSecrets(request.connection, request.message);
@@ -404,7 +408,29 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
         }
     }
 
-    if (requestNew || (allowInteraction && !setting->needSecrets(requestNew).isEmpty()) || (allowInteraction && userRequested) || (isVpn && allowInteraction)) {
+    if (!Configuration::showPasswordDialog()) {
+        sendError(SecretAgent::NoSecrets, "Cannot authenticate", request.message);
+        emit secretsError(request.connection_path.path(), i18n("Authentication to %1 failed. Wrong password?", request.connection.value("connection").value("id").toString()));
+        return true;
+    } else if (isWireGuard && userRequested) { // Just return what we have
+        NMVariantMapMap result;
+        NetworkManager::WireGuardSetting::Ptr wireGuardSetting;
+        wireGuardSetting = connectionSettings->setting(NetworkManager::Setting::WireGuard).dynamicCast<NetworkManager::WireGuardSetting>();
+        //FIXME workaround when NM is asking for secrets which should be system-stored, if we send an empty map it
+        // won't ask for additional secrets with AllowInteraction flag which would display the authentication dialog
+        if (wireGuardSetting->secretsToMap().isEmpty()) {
+            // Insert an empty secrets map as it was before I fixed it in NetworkManagerQt to make sure NM will ask again
+            // with flags we need
+            QVariantMap secretsMap;
+            secretsMap.insert(QLatin1String("secrets"), QVariant::fromValue<NMStringMap>(NMStringMap()));
+            result.insert("wireguard", secretsMap);
+        } else {
+            result.insert("wireguard", wireGuardSetting->secretsToMap());
+        }
+        sendSecrets(result, request.message);
+        return true;
+    } else if (requestNew || (allowInteraction && !setting->needSecrets(requestNew).isEmpty()) || (allowInteraction && userRequested) || (isVpn && allowInteraction)) {
+
         m_dialog = new PasswordDialog(connectionSettings, request.flags, request.setting_name);
         connect(m_dialog, &PasswordDialog::accepted, this, &SecretAgent::dialogAccepted);
         connect(m_dialog, &PasswordDialog::rejected, this, &SecretAgent::dialogRejected);
@@ -465,7 +491,7 @@ bool SecretAgent::processSaveSecrets(SecretsRequest &request) const
             }
 
             if (m_wallet->setFolder("Network Management")) {
-                Q_FOREACH (const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
+                for (const NetworkManager::Setting::Ptr &setting : connectionSettings.settings()) {
                     NMStringMap secretsMap = setting->secretsToStringMap();
 
                     if (!secretsMap.isEmpty()) {
@@ -501,9 +527,9 @@ bool SecretAgent::processDeleteSecrets(SecretsRequest &request) const
         if (m_wallet->isOpen()) {
             if (m_wallet->hasFolder("Network Management") && m_wallet->setFolder("Network Management")) {
                 NetworkManager::ConnectionSettings connectionSettings(request.connection);
-                Q_FOREACH (const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
+                for (const NetworkManager::Setting::Ptr &setting : connectionSettings.settings()) {
                     QString entryName = QLatin1Char('{') % connectionSettings.uuid() % QLatin1Char('}') % QLatin1Char(';') % setting->name();
-                    Q_FOREACH (const QString &entry, m_wallet->entryList()) {
+                    for (const QString &entry : m_wallet->entryList()) {
                         if (entry.startsWith(entryName)) {
                             m_wallet->removeEntry(entryName);
                         }
@@ -557,7 +583,7 @@ bool SecretAgent::useWallet() const
 bool SecretAgent::hasSecrets(const NMVariantMapMap &connection) const
 {
     NetworkManager::ConnectionSettings connectionSettings(connection);
-    Q_FOREACH (const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
+    for (const NetworkManager::Setting::Ptr &setting : connectionSettings.settings()) {
         if (!setting->secretsToMap().isEmpty()) {
             return true;
         }
@@ -581,7 +607,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
 
     // No action is required when the list of secrets is empty
     if (!config.groupList().isEmpty()) {
-        Q_FOREACH (const QString &groupName, config.groupList()) {
+        for (const QString &groupName : config.groupList()) {
             QString loadedUuid = groupName.split(';').first().remove('{').remove('}');
             QString loadedSettingType = groupName.split(';').last();
             NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(loadedUuid);
@@ -590,7 +616,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
                 QMap<QString, QString> secrets = config.entryMap(groupName);
                 NMVariantMapMap settings = connection->settings()->toMap();
 
-                Q_FOREACH (const QString &setting, settings.keys()) {
+                for (const QString &setting : settings.keys()) {
                     if (setting == QLatin1String("vpn")) {
                         NetworkManager::VpnSetting::Ptr vpnSetting = connection->settings()->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
                         if (vpnSetting) {
@@ -600,7 +626,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
                             NMStringMap vpnData = vpnSetting->data();
                             // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
                             // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
-                            Q_FOREACH (const QString &key, vpnData.keys()) {
+                            for (const QString &key : vpnData.keys()) {
                                 if (key.endsWith(QLatin1String("-flags"))) {
                                     vpnData.insert(key, QString::number((int)secretFlags));
                                 }
@@ -615,7 +641,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
                             QVariantMap tmpSetting = settings.value(setting);
                             // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
                             // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
-                            Q_FOREACH (const QString &key, tmpSetting.keys()) {
+                            for (const QString &key : tmpSetting.keys()) {
                                 if (key.endsWith(QLatin1String("-flags"))) {
                                     tmpSetting.insert(key, (int)secretFlags);
                                 }
