@@ -39,6 +39,7 @@
 #include "settings/wifisecurity.h"
 #include "settings/wiredconnectionwidget.h"
 #include "settings/wiredsecurity.h"
+#include "settings/wireguardinterfacewidget.h"
 #include "vpnuiplugin.h"
 
 #include <NetworkManagerQt/ActiveConnection>
@@ -100,7 +101,7 @@ NMVariantMapMap ConnectionEditorBase::setting() const
 {
     NMVariantMapMap settings = m_connectionWidget->setting();
 
-    Q_FOREACH (SettingWidget *widget, m_settingWidgets) {
+    for (SettingWidget *widget : m_settingWidgets) {
         const QString type = widget->type();
         if (type != NetworkManager::Setting::typeAsString(NetworkManager::Setting::Security8021x) &&
                 type != NetworkManager::Setting::typeAsString(NetworkManager::Setting::WirelessSecurity)) {
@@ -132,6 +133,8 @@ NMVariantMapMap ConnectionEditorBase::setting() const
 
     connectionSettings->fromMap(settings);
     connectionSettings->setId(connectionName());
+    if (connectionSettings->connectionType() == NetworkManager::ConnectionSettings::WireGuard)
+        connectionSettings->setInterfaceName(connectionName());
     connectionSettings->setUuid(m_connection->uuid());
 
     if (connectionSettings->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
@@ -144,7 +147,6 @@ NMVariantMapMap ConnectionEditorBase::setting() const
             }
         }
     }
-
     return connectionSettings->toMap();
 }
 
@@ -240,6 +242,9 @@ void ConnectionEditorBase::initialize()
     } else if (type == NetworkManager::ConnectionSettings::Team) { // Team
         TeamWidget *teamWidget = new TeamWidget(m_connection->uuid(), m_connection->setting(NetworkManager::Setting::Team), this);
         addSettingWidget(teamWidget, i18n("Team"));
+    } else if (type == NetworkManager::ConnectionSettings::WireGuard) { // WireGuard
+        WireGuardInterfaceWidget *wireGuardInterfaceWidget = new WireGuardInterfaceWidget(m_connection->setting(NetworkManager::Setting::WireGuard), this);
+        addSettingWidget(wireGuardInterfaceWidget, i18n("WireGuard Interface"));
     } else if (type == NetworkManager::ConnectionSettings::Vpn) { // VPN
         QString error;
         VpnUiPlugin *vpnPlugin = nullptr;
@@ -278,17 +283,13 @@ void ConnectionEditorBase::initialize()
     if ((type == NetworkManager::ConnectionSettings::Wired
             || type == NetworkManager::ConnectionSettings::Wireless
             || type == NetworkManager::ConnectionSettings::Infiniband
-#if NM_CHECK_VERSION(0, 9, 10)
             || type == NetworkManager::ConnectionSettings::Team
-#endif
-
-#if NM_CHECK_VERSION(1, 0, 0)
             || type == NetworkManager::ConnectionSettings::Cdma
             || type == NetworkManager::ConnectionSettings::Gsm
-#endif
             || type == NetworkManager::ConnectionSettings::Bond
             || type == NetworkManager::ConnectionSettings::Bridge
             || type == NetworkManager::ConnectionSettings::Vlan
+            || type == NetworkManager::ConnectionSettings::WireGuard
             || (type == NetworkManager::ConnectionSettings::Vpn && serviceType == QLatin1String("org.freedesktop.NetworkManager.openvpn"))) && !m_connection->isSlave()) {
         IPv6Widget *ipv6Widget = new IPv6Widget(m_connection->setting(NetworkManager::Setting::Ipv6), this);
         addSettingWidget(ipv6Widget, i18n("IPv6"));
@@ -296,7 +297,7 @@ void ConnectionEditorBase::initialize()
 
     // Re-check validation
     bool valid = true;
-    Q_FOREACH (SettingWidget *widget, m_settingWidgets) {
+    for (SettingWidget *widget : m_settingWidgets) {
         valid = valid && widget->isValid();
         connect(widget, &SettingWidget::validChanged, this, &ConnectionEditorBase::validChanged);
     }
@@ -357,6 +358,13 @@ void ConnectionEditorBase::initialize()
                     setting = securitySetting->toMap();
                     settingName = QLatin1String("802-1x");
                 }
+            } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::WireGuard) {
+                NetworkManager::WireGuardSetting::Ptr securitySetting = connection->settings()->setting(NetworkManager::Setting::WireGuard).staticCast<NetworkManager::WireGuardSetting>();
+                if (securitySetting && !securitySetting->needSecrets().isEmpty()) {
+                    requiredSecrets = securitySetting->needSecrets();
+                    setting = securitySetting->toMap();
+                    settingName = QLatin1String("wireguard");
+                }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
                 NetworkManager::WirelessSecuritySetting::Ptr wifiSecuritySetting = connection->settings()->setting(NetworkManager::Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
                 if (wifiSecuritySetting &&
@@ -397,7 +405,7 @@ void ConnectionEditorBase::initialize()
                         }
                     }
                 } else {
-                    Q_FOREACH (const QString &secret, requiredSecrets) {
+                    for (const QString &secret : requiredSecrets) {
                         if (setting.contains(secret + QLatin1String("-flags"))) {
                             NetworkManager::Setting::SecretFlagType secretFlag = (NetworkManager::Setting::SecretFlagType)setting.value(secret + QLatin1String("-flags")).toInt();
                             if (secretFlag == NetworkManager::Setting::None || secretFlag == NetworkManager::Setting::AgentOwned) {
@@ -436,12 +444,12 @@ void ConnectionEditorBase::replyFinished(QDBusPendingCallWatcher *watcher)
     const QString settingName = watcher->property("settingName").toString();
     if (reply.isValid()) {
         NMVariantMapMap secrets = reply.argumentAt<0>();
-        Q_FOREACH (const QString &key, secrets.keys()) {
+        for (const QString &key : secrets.keys()) {
             if (key == settingName) {
                 NetworkManager::Setting::Ptr setting = m_connection->setting(NetworkManager::Setting::typeFromString(key));
                 if (setting) {
                     setting->secretsFromMap(secrets.value(key));
-                    Q_FOREACH (SettingWidget *widget, m_settingWidgets) {
+                    for (SettingWidget *widget : m_settingWidgets) {
                         const QString type = widget->type();
                         if (type == settingName ||
                                 (settingName == NetworkManager::Setting::typeAsString(NetworkManager::Setting::Security8021x) &&
@@ -476,7 +484,7 @@ void ConnectionEditorBase::validChanged(bool valid)
         Q_EMIT validityChanged(false);
         return;
     } else {
-        Q_FOREACH (SettingWidget *widget, m_settingWidgets) {
+        for (SettingWidget *widget : m_settingWidgets) {
             if (!widget->isValid()) {
                 m_valid = false;
                 Q_EMIT validityChanged(false);
